@@ -22,7 +22,7 @@ use strict;
 use vars qw($AUTOLOAD $VERSION $ABSTRACT @ISA @EXPORT);
 
 BEGIN {
-	$VERSION = 0.23;
+	$VERSION = 0.24;
 	$ABSTRACT = "Fast HTML Parser using Threads with no outside dependencies";
 	
 	@ISA = qw(Exporter DynaLoader);
@@ -162,7 +162,7 @@ See latest version on L<https://github.com/lexborisov/perl-html-myhtml|https://g
  
  # print result
  print "Print HTML Tree:\n";
- $tree->document->print_childs($tree, *STDOUT, 0);
+ $tree->document->print_children($tree, *STDOUT, 0);
  
  print "\nGet all DIV elements of HTML Tree:\n";
  my $list = $tree->get_elements_by_tag_name("div");
@@ -676,11 +676,11 @@ Print a node
 
  $node->print($tree, $fh, $inc);
 
-=head3 print_childs
+=head3 print_children
 
 Print tree of a node. Print excluding current node
 
- $node->print_childs($tree, $fh, $inc);
+ $node->print_children($tree, $fh, $inc);
 
 =head3 print_all
 
